* [based on Hamilton L. C. (2013). Statistics with STATA: Version 12, 8th Edition. Cengage. University of New Hampshire, Ch. 3]

version 12.1
clear all
set more off

* ### Patterns of missing values ###
* ##################################

* Create a small dataset

import excel using Missing_values.xlsx, firstrow clear
describe

* #####################################################################
* ### 1. Number of missing values vs. number of non missing values ###

* The first thing to do to examine the dataset for missing values is to determine which variables have a lot of missing values. 

* There is a small Stata program called "mdesc" that counts the number of missing values in both numeric and character variables. 
// You can download "mdesc" from within Stata by typing "findit mdesc"

* Run "mdesc" for one or more variables.

 mdesc 
 
// Now we know the number of missing values in each variable. 
// For instance, variable salepric has four missing values and saltoapr has two missing values.

* #################################################################
* ### 2. Obtaining the number of missing values per observation ###

* We can also look at the distribution of missing values across observations. 
// The code below creates a variable called "nmis" that gives the number of missing values for each observation. 
// The function "rmiss2()" used here is an extension to the egen function "rmiss()". 
// It counts the number of missing values in the varlist. 
// rmiss2() accepts both string and numeric variables. (Stata's rmiss() only accepts numeric variables.) 

// You can download rmiss2() over the internet from within Stata by typing "findit rmiss2".

egen nmis=rmiss2(landval improval totval salepric saltoapr)

* Below we tabulate the variable we just created. 

tab nmis

// Looking at the frequency table we know that there are four observations with no missing values, 
// nine observations with one missing values, one observation with two missing values and one observation with three missing values.


* #####################################
* ### 3. Patterns of missing values ###

* To look at the patterns of missing values, you can download "mvpatterns" over the internet from within Stata by typing "findit mvpatterns"
// The command "mvpatterns" produces output for all variables in the dataset, for missing data patterns across a subset of variables, 
// a variable list can be included, for example: "mvpatterns landval improval totval".

mvpatterns

// The first table lists the variables, their storage type (type), the number of observations (obs), 
// the number of missing values (mv), and the variable label if the variables has one. 

// The second table contains the information on the pattern of missing values. 
// The first block of columns in the output shows the patterns of missing data. 
// Within the block, each variable is represented by a column, 
// a "+" indicates that values of that variable are present in a given missing data pattern, 
// a "." indicates that they are missing. 
// The columns follow the same order as the variable list in the first table, 
// so that the first column in the output below represents landval, the second improval, and so on. 

// The missing data patterns are listed in descending frequency, here the most common missing data pattern is complete data ("+++++"). 
// The table also shows the number of missing values in that pattern (_mv), and the number of cases with that missing data pattern (_freq). 
// Based on the information in the second table we know that there are four observations with no missing values, 
// two cases missing on just the variable salepric, and one observation with missing values on improval, salepric and saltoapr, and so on.


* #########################################################
* ### 4. When all the variables of interest are numeric ###

* The examples above all work regardless of whether the variables of interest 
// (i.e. the variables whose missing data patterns you want to examine) are numeric or string. 

* When all of the variables you wish to check for missing values are numeric we can use a program called "misschk"
// to simplify the steps of examining the missing data in our dataset. 

// (Note: numeric variables include those with value labels that are strings, as long as the actual values of the variables are stored as numbers.) 

// You can download "misschk" from within Stata by typing "findit misschk"

misschk landval improval totval salepric saltoapr, gen(miss)

// We have listed all five of the variables in our dataset in the variable list after the misschk command. 
// However, we could have just left the list of variables blank (i.e. used only misschk , gen(miss) instead), 
// if we had, "misschk" would have run using all the variables in our dataset. 

// The "gen(miss)" option tells "misschk" that we want it to create two new variables, both of which start with "miss". 
// These two variables will be named "misspattern" and "missnumber". 
// The variable "misspattern" indicates which of the missing data patterns each case follows. 
// The variable "missnumber" indicates the number of missing values for each case.

* The output for misschk consists of three tables. 
// The first table lists the number of missing values, as well as percent missing for each variable, 
// this is similar to the table produced by "mdesc" in part 1 above. 
// This table also contains a column labeled "#" which assigns each variable a number that is used to identify the variable later on in the output. 

// The second table shows the distribution of missing values. 
// The pattern of missingness is described using the variable numbers from the first table, and underscores ("_"). 
// The numbers indicate which variables are missing in that pattern, the underscores represent non-missing observations. 
// For example, from the second table we see that two cases have missing values on variable 1 (landval), 
// but complete data on all other variables, and that one case is missing data on variables 2, 4, and 5. 
// The bottom row shows that four cases are not missing any values at all (all underscores). 
// This table shows the same information generated in part three above, but in a slightly different format. 
// The missing data pattern for each case is described in the variable misspattern. 

// Finally, the third table shows the distribution of the number of missing values per case. 
// This is the same information discussed above in part 2. The number of variables each case is missing is also contained in the variable missnumber.


* ### Summary Statistics and Tables ###
* ########################################

* The summary of statistics is best divided into two cases - case of categorical variables and
// case of continuous variables; lets start with the more general case of continuous varaibles

* ########################################################
* ### Summary Statistics for Measurement (continuous) Variables ###

* Dataset electricity.dta contains information on electricity consumption in U.S. states
use electricity.dta, clear
describe

* ### summarize

* To find the basic statistics of per capita electricity use (elcap), type
summarize elcap

* To see more detailed summary statistics, type
summarize elcap, detail

// "summarize, detail" output includes basic statistics plus the following:
* # Percentiles: Notably the first quartile (25th percentile = 10,359), median (50th percentile = 13,388), and third quartile (75th percentile = 16,117). 
// Because many samples do not divide evenly into quarters or other standard fractions, these percentiles are approximations.
/* A percentile is a measure indicating the value below which a given percentage of observations in a group of observations fall. */
* # Four smallest and four largest values, where outliers might show up.
* # Sum of weights: the summarize command permits frequency weights or fweight. For explanations see "help weight".
/// (or this seems to ptovide a clear explanation http://www.ats.ucla.edu/stat/stata/output/stata_summ_output.htm).
* # Variance: Standard deviation squared.
* # Skewness: The direction and degree of asymmetry. A perfectly symmetrical distribution has skewness = 0. 
// Positive skew (heavier left tail) results in skewness > 0; negative skew (heavier right tail) results in skewness < 0.
* # Kurtosis: Tail weight. A normal (Gaussian) distribution is symmetrical with kurtosis = 3. 
// If a symmetrical distribution has heavier-than-normal tails (is sharply peaked), then kurtosis > 3.
// Kurtosis < 3 indicates lighter-than-normal tails.

* ### tabstat

* The "tabstat" command provides a more flexible alternative to summarize. We can specify just which summary statistics we want to see. 
// Type "help tabstat" to see a complete list.
tabstat elcap, stats(mean min max)

* With a by(varname) option, tabstat constructs a table containing summary statistics for each value of varname. 
// The following example gives means, minimum and maximum for per capita electricity use, separately for each of four U.S. census regions. 
tabstat elcap, stats(mean min max) by(region4)

* ##########################################################
* ###  Frequency Tables and Two-Way Cross-Tabulations ###

* The summary statistics described above apply mainly to measurement variables. 
* Categorical variables require different approaches, often starting with simple one- or two-way tables. 
// Using such tables we return to the Granite State Poll data, Granite2011_6.dta. 
// One question (trackus) asked whether people think the U.S. is headed in the right direction, or is on the wrong track. 

* ### tabulate

use Granite2011_6.dta, clear
tabulate trackus

// "tabulate" can produce frequency distributions for variables that have thousands of values. 

* "tabulate" followed by two variable names creates a two-way cross-tabulation. 
// For example, here is a cross-tabulation of trackus by educ (respondents level of education):

tabulate educ trackus

// The first-named variable forms the rows, and the second forms columns in the resulting table.

* "tabulate" has a number of options that are useful with two-way tables. 
// For example, the option missing requests that missing values be included among the rows or columns of the table. 
// "tabulate" can also save frequencies and variables names as matrices. 
// Type "help tabulate" for list of options with details.


* ###########################################################
* ###  Multiple Tables and Multi-Way Cross-Tabulations ###

* With surveys and other large datasets, we sometimes need frequency distributions of many different variables. 
// Instead of asking for each table separately, for example by typing tabulate tparty, 
// then tabulate obama, and finally tabulate trackus, we could simply use another specialized command, "tab1":

tab1 tparty obama trackus

// To produce one-way frequency tables for each variable from tparty through trackus in this dataset (the maximum is 30 variables at one time), type

tab1 tparty-trackus

* "tab2" creates multiple two-way tables. 
// For example, the following command crosstabulates every two-way combination of the listed variables:

tab2 tparty obama trackus

// tab1 and tab2 offer the same options as tabulate.

* To form multi-way contingency tables, it is possible to use tabulate with a by prefix.

tab obama college, col nof

// One way to make a three-way cross-tabulation of the obama/college relationship by gender is to use sort and the by: prefix. 
// This produces two-way tables with the same layout as above, but separately for males and females.

by sex, sort: tab obama college, col nof
bysort sex: tab obama college, col nof

* To get a four-way crosstabulation of obama by college, with separate sub-tables for married and unmarried men and women, 
// we could type the commands (results not shown):

by sex married, sort: tab obama college, col nof
bysort sex married: tab obama college, col nof

* ### table

* Alternative way to produce multi-way tables is through Stata's general table-making command, "table". 
// This command has many options, only a few of which are illustrated here. 
// To construct a two-way table of obama by college, with frequencies in each cell, type

table obama college, contents(freq)

* If we specify a third categorical variable, it forms the supercolumns of a three-way table:

table obama college sex, contents(freq)

// More complicated tables require the by( ) option, which allows up to four supperrow variables.
// "table" thus can produce up to seven-way tables: one row, one column, one supercolumn, and up to four superrows. 
// Here is a four-way example:

table obama college sex, contents(freq) by(married)

// The table examples above all place frequencies in the cells, but table permits statistical summaries as well. 
// Here is a four-way table, obama * college * sex * married, in which each cell contains the mean age for that combination of characteristics. 

table obama college sex, contents(mean age) by(married)

// For example, we see that the 34 non-college, unmarried men who did not vote for Obama have a mean age of 46.6 years.

* The contents( ) option of table specifies what statistics the tables cells contain. 
// The choices include not just frequency or mean, but also standard deviation, minimum, maximum, median, range, percentiles and other summaries. 
// Type help table for a full list.


* #################################################################
* ### Tables of Means, Medians and Other Summary Statistics ###

* "tabulate" produces tables of means and standard deviations within categories of the tabulated variable. 
// For the remaining examples in this chapter, we return to the data on electricity consumption in U.S. states. 
// "tabulate" gives us one way to view summary statistics of per capita electricity consumption (elcap) for each of the 9 U.S. census divisions (region9):

use electricity.dta, clear
tabulate region9, summ(elcap)

* We could also use tabulate to form a two-way table of means using the 9 census divisions and 4 census regions:

tabulate region9 region4, summ(elcap) mean

* The means option above called for a table containing only means. 
// Otherwise we get a bulkier table with means, standard deviations and frequencies within each cell.

* The more flexible "table" command can build up to seven-way tables containing means, standard deviations, sums, medians or other statistics. 
// For illustration, here is a one-way table showing mean and standard deviation of per capita electricity use 
// and also the median and interquartile range of population, within each census division.

table region9, contents (mean elcap sd elcap median pop iqr pop)

/* important part of summary statistics, and many estimation stata commands in general, is accessing results of the commands, 
so that they can be further used in future commands; 
every stata estimation command has list of values which is stores as results; 
if the command is such that it describes data but does not estimate parameters, so called r-class command,
and its results are stored in r() scalars; the whole list can be displayed after the command "return list", 
or viewed in the help widnow */ 
  
/* it is crucial to recognize that stata stores the reuls of the last r-class commmand only -
if we run new estimation command, new return list is stored; 
therefore  if we want to use the results in future we have to immediately store them as new scalars/matrices */


* #####################################
* ### Explanatory data analysis ###

* The "stem-and-leaf display" is one of the explanatory data analysis methods.
// It is a graphical arrangement of ordered data values in which initial digits form the stems 
// and following digits for each observation make up the leaves

use electricity.dta, clear
stem elcap

// In this display the lowest per capita electricity value, 6,721 (California), appears as a 721 leaf on the 6*** stem. 
// The highest, 27,457 (Wyoming), appears as a 457 leaf on the 27*** stem.
// "stem" automatically chooses values for the stems, but can override this with a lines( ) option.
// Type help stem for information about this option and others.

// The "stem-and-leaf display" can be useful when looking for the outliers

* ### 3. Graphs ###
* #################

* ######################
* ### 3.1 Histograms ###

* The command "histogram" displays the distribution of measurement variables. 

* Consider dataset Nations2.dta, which contains human-development indicators gathered by the United Nations.

use Nations2.dta, clear
describe
histogram adfert, percent

// The Figure shows a simple histogram of adfert, the adolescent fertility rate.

* Options can be listed in any order following the comma in a graph command. 
// Figure above illustrates one option: percent (instead of density, the default) is shown on the vertical axis.
// Once a graph is on screen, menu choices provide the easiest way to print it, save it to disk, 
// or copy and paste it into another program such as a word processor.

* The next Figure contains a version of the same histogram but with some optional improvements:

histogram adfert, frequency start(0) width(10) ///
xlabel(0(20)200) xtick(10(20)210) ///
ylabel(0(5)35, grid gmax) ///
title("Adolescent fertility rate in 194 nations") ///
note(a)

* # frequency Frequencies are shown on the vertical (y) axis.
* # start(0) The histogram's first bar (bin) starts at 0.
* # width(10) The width of each bar (bin) is 10.
* # xlabel(0(20)200) The x axis is labeled from 0 to 200, in increments of 20.
* # xtick(10(20)210) The x axis has tick marks from 10 to 210, in increments of 20.
* # ylabel(0(5)35, grid gmax) The y axis is labeled from 0 to 35, in increments of 5. 
// A grid of horizontal lines is drawn, including a line at the maximum value.
* # title("Adolescent fertility rate in 194 nations") The graph has a title at top.

* One option that histogram shares with other graph types is the ability to create multiple small graphs for each value of a specified variable, 
// using a by(varname) option. 
* The next Figure illustrates histograms of adfert for each of the five regions, along with a sixth (total) histogram showing the distribution for all regions.

histogram adfert, percent start(0) width(10) by(region, total)

****add note here!!!!!
histogram adfert if region==1, percent start(0) width(10)


* #####################
* ### 3.2 Box Plots ###

* Box plots convey information about center, spread, symmetry and outliers at a glance. 

* The next Figure is a simple box plot of adfert (adolescent fertility rate)

graph box adfert

/* Box plots in general are composed of a box, two whiskers, two fences, and some marker symbols. The box is the rectangle in the middle of the graph. 
The lower border of the box is the first quartile; the upper border is the third quartile. The line in the middle of the box is the median.
The height of the box therefore shows the interquartile range.

The whiskers are two vertical lines below and above the box, which end with small horizontal lines called the fences.
The upper fence is the highest value of the distribution that is smaller than or equal to the third quartile plus 1.5 times the interquartile range.
The lower fence is the lowest value of the distribution that is greater than or equal to the first quartile minus 1.5 times the interquartile range.

Observations below the lower fence or above the upper fence are regarded as outliers and are plotted with single plot symbols.

Box plots provide much information about a distribution. You can directly infer the position of the distribution from the position of the box along the y axis.
Fifty percent of the observations have values between the lower and upper bounds of the box.
You can infer the dispersion of the distribution by the size of the box, by the length of the whiskers, and by the positions of the outliers.
Moreover, you can see the symmetry or skewness of the distribution: in symmetric distributions, the distances between the median and the lower
and upper bounds of the box are equal. Also the whiskers should be of equal length and the outliers above and below should be equally spaced.
If the outliers, the whiskers, or the box are squeezed at the bottom, the distribution is skewed to the right.
If they are squeezed at the top, it is skewed to the left. */

// From the Figure one can conclude about the positive skew of this distribution. One can also see five high outliers. 

* The next Figure identifies the adfert outliers by labeling their markers with values of variable country (country names). 
// It also specifies a non-default title for the y axis. 
// Specifying marker(1) in this example means that this option refers to the first-named y variable. 
// There is only one y variable here, but in other cases we could have two or more, and mark their outliers in distinct ways.

graph box adfert, marker(1, mlabel(country)) ///
ytitle("Births per 1,000 females 15-19")

* One of the most common applications for box plots involves comparing the distribution of one variable over categories of a second 
// using the options over() or by().. 

// The next Figure compares the distribution of adfert across region. 
// The overall median is indicated by a horizontal line placed by the yline(39.3) option.

graph hbox adfert, marker(1, mlabel(country)) yline(39.2) over(region)

* or can automote the process
sum adfert
return list
* mean value for the variable is stored under name "r(mean)", let's use it in yline specification with the right quotes
graph hbox adfert, marker(1, mlabel(country)) yline(`r(mean)') over(region)

* Box plots can have a horizontal orientation instead of vertical, via the "graph hbox command".

* The next Figure illustrates using per capita carbon dioxide emissions (CO2)
// This example also shows off several title or labeling options, which could be applied to any type of graph. 
// The note( ) and caption( ) options place text below the graph.
// In this figure, Statistics with Stata appears in bold, and Example of horizontal box plots in italics. 
// In the ytitle (y axis title, which in a horizontal box plot refers to the horizontal axis), CO2 is given its proper subscript. 
// Type "help graph text" to see other possibilities and examples.

graph hbox co2, over(region) ///
note("note: {bf:Statistics with Stata}, version 12") ///
caption("caption: United Nations Human Development Report 2011") ///
title("title: {it:Example of horizontal box plots}") ///
ytitle("ytitle: Tons of CO{subscript:2} emitted per capita")

// Numerous options control the appearance, shading and details of boxes in a box plot; type "help graph box" for a list. 


* #####################################
* ### 3.3 Scatterplots and Overlays ###

* Scatterplots belong to a broad family called twoway graphs. 
// Statas basic scatterplot command has the form

// "graph twoway scatter y x"

* Consider the Nations2.dta dataset
* We can plot life (life expectance) against school (mean years of schooling), with the result shown in the next Figure

graph twoway scatter life school

// Each point in the Figure represents one nation.

* We can use xlabel, xtitle, ylabel and so forth to control x or y axis labels, titles etc. 
* Scatterplots also allow control of the shape, color, size, labeling and other attributes of markers. 
// Type "help scatter" for a complete list of markers and other options.
// Type "help colorstyle" for a list of available colors, which can also apply to bars, lines, text and other elements of any Stata graph.

* One interesting possibility with scatterplots is to make symbol size (area) proportional to a third variable, 
// thereby giving the data points different visual weight. 

// This is done in the next Figure, using the [fweight=varname] or frequency weight feature. Hollow circles, msymbol(Oh), provide a suitable shape.

graph twoway scatter life school [fweight=pop], msymbol(Oh)

* A key feature of Statas graph twoway family is that we can overlay two or more graphs to build more complex images. 
// For example, to draw a scatterplot of life against school, with hollow circles as marker symbols, we would type

// "graph twoway scatter life school, msymbol(Oh)"

// Simple regression lines (lfit) are a different twoway type. 
// To see the line for life regressed on school, with a line of medium-thick width, type

// "graph twoway lfit life school, lwidth(medthick)"

* But often we want to see the scatterplot and regression line together. 
// That is accomplished by overlaying the lfit graph on top of the scatter graph using one command with || (pipes) to indicate the overlay.

graph (twoway scatter life school [fweight=pop]), msymbol(Oh) ///
|| lfit life school, lwidth(medthick)

// Finally, if we have certain options that should apply to the image as a whole, 
// these can be placed in the command after a final ||.

graph twoway scatter life school, msymbol(Oh) ///
|| lfit life school, lwidth(medthick) ///
|| , ylabel(45(5)85) xlabel(2(2)12) xtick(1(2)13) ///
legend(col(1) ring(0) position(11))

// The legend option in the Figure specifies three things:
* # col(1) The legend should have just one column, and hence two rows.
* # ring(0) The legend is placed within the plot region, instead of outside it. 
// A legend outside the plot region crowds the data into a smaller space.
* # position(11) The legend goes at the 11 oclock position, which in this graph happens to be empty of data.

* # A similar command, "graph twoway qfit", draws a quadratic or second-order polynomial regression curve.

* Scatterplot matrices are not twoway plot types and cannot be overlaid with other graphs, 
// but they involve multiple scatterplots that follow the same marker symbol conventions. 

// A scatterplot matrix is the visual counterpart to a correlation matrix, which can be useful in multivariate analysis. 
// They provide a compact display of relationships between a number of variable pairs, 
// allowing the analyst to scan for signs of nonlinearity, outliers or clustering that might affect statistical modeling. 

* The next Figure shows a scatterplot matrix for five variables from Nations2.dta.

graph matrix gdp school adfert chldmort life, msymbol(oh)

// Nonlinear relationships involving gdp (per capita Gross Domestic Product) stand out prominently in the Figure,
// giving a warning we would not see from the correlation matrix alone.

// "msymbol(oh)" called for small circles as markers. 
// Control of the axes is more complicated, because there are as many axes as variables; 
// type "help graph matrix" for details.

// The "half" option specifies that Figure should include only the lower triangular part of the matrix. 

graph matrix gdp school adfert chldmort life, half msymbol(oh)

// The upper triangular part is symmetrical and basically redundant. 


* ###############################################
* ### 3.4 Line Plots and Connected-Line Plots ###

* Mechanically, connected-line plots (graph twoway connect) are just scatterplots in which the points are connected by line segments. 
* Line plots (graph twoway line) show the line segments without markers for the scatterplot points. 
// Both belong to Statas versatile graph twoway family, which can be overlaid in any combinations. 
// The scatterplot options that control axis labeling and markers work much the same with connected-line and line plots as well. 
// Further options control width, pattern, color and other characteristics of the lines themselves.

* Connected-line and line plots tend to have different uses than scatterplots. 
// For example, they serve well to graph changes in a variable over time. 

// To illustrate, we use dataset Arctic9.dta, which contains 33 years of Arctic sea ice and temperature observations.

use Arctic9.dta, clear
describe

graph twoway line area year, ///
title("Arctic sea ice, September 1979-2011")

* The next Figure adds a second line for sea ice extent (the area covered by at least 15% ice). 

graph twoway line area extent year, xlabel(1980(5)2010) xtitle("") ///
lwidth(medium medthick) lpattern(solid dash) ///
legend(row(2) ring(0) position(9) ///
label(1 "Area") label(2 "Extent") order(2 1)) ///
ylabel(0(1)8, grid gmin gmax) ytitle("Million km{superscript:2}") ///
title("Arctic sea ice, September 1979`=char(150)'2011")

// We label the x axis from 1980 to 2010 in 5-year increments (xlabel(1980(5)2010) 
// The y axis extends down to zero, a possible state of some interest to Arctic observers. 
// Y axis labels go from 0 to 8 in increments of 1, 
// with grid lines including the minimum (0) and maximum (8) labeled values: ylabel(0(1)8, grid gmin gmax).

// The first-named y variable in the Figure command (area) is graphed with a line of medium width and solid pattern. 
// The second y variable (extent) is graphed with a heavier line of medium-thick (medthick) width and dashed pattern. 
// legend() options simplify the labels in the legend, and place extent first corresponding to its higher position in the graph.
// Ice area and extent are measured in millions of square kilometers. 
// The ytitle(Million km{superscript:2}) option displays this as Million km^2 . 
// Type "help graph text" for more about controlling text attributes in graphs. 
// The title option for the Figure inserted ASCII (The American Standard Code for Information Interchange) character 150 (n-dash ()) 
// between 1979 and 2011 by writing 1979`=char(150)'2011. 
// Note the use of left and right single quotes.

* The next Figure overlays a line plot of area vs. year with a connected-line plot 
// (connect, which combines the features of scatter with line) of Arctic temperature vs. year. 

graph twoway line area year, ylabel(0(1)6) yline(0) ///
ytitle("Ice area, million km{superscript:2}") ///
|| connect tempN year, yaxis(2) ylabel(-1(1)2, ///
axis(2)) msymbol(+) ///
ytitle("Arctic temperature anomaly, `=char(186)'C", axis(2)) ///
|| , xlabel(1980(5)2010) xtitle("") ///
legend(row(2) ring(0) position(6) ///
label(1 "Ice area") label(2 "Temperature") order(1 2)) ///
title("Arctic September sea ice and annual temperature, 1979`=char(40)'2011", size(medium))

// The graph shows September sea ice declining as annual Arctic air temperatures rise.

// In the Figure, Arctic temperature anomaly is assigned to yaxis(2), which is the right-hand y axis. 
// Temperature values are marked as plus signs (msymbol(+)). 
// A legend inside the data region at 6 oclock position identifies the two variables. 
// On the right-hand y axis, ASCII character 186 provides the degree symbol for C.

// The Figure illustrated the simplest connect style, in which data points are connected by straight line segments. 
// For more details, see "help connectstyle".

* The next Figure gives a table of ASCII codes, drawn by a convenient utility named "asciiplot". 
// Type "findit asciiplot" for instructions on how to download and install this program.

asciiplot


* ###################################
* ### 3.5 Other Twoway Plot Types ###

* In addition to basic line plots and scatterplots, the graph twoway command can draw a wide variety of other types. 
// Type "help graph twoway" for a complete list.

* #####################################
* ### 3.6 Bar Charts and Pie Charts ###

* # Bar Charts

* The "graph bar" command works well to display relationships involving one or more categorical variables. 

* Consider a cross-national dataset Nations2.dta.

use Nations2.dta, clear
describe region gdp pop

* To make the bar chart readable, start by generating a new variable, gdp1000, expressing Gross Domestic Product in thousands of dollars.

generate gdp1000 = gdp/1000
summarize gdp gdp1000

* The next Figure depicts the mean and median of gdp1000 over values of region, using "graph bar".

graph bar (mean) gdp1000 (median) gdp1000, over(region) ///
ytitle("Per capita GDP, thousands of 2005 US dollars") ///
blabel(bar, format(%3.1f)) ///
bar(1, color(blue)) bar(2, color(orange)) ///
legend(ring(0) position(11) col(2) label(1 "Mean") ///
label(2 "Median") symxsize(*.5))

* The Figure includes labels giving the height of each bar, displayed in numerical format(%3.1f)  
// which means a fixed format with three digits, one of them right of the decimal. 

// "graph bar" can display not only means or medians but also other statistics including various percentiles, minimum, maximum or count. 
// It also could show these statistics for more than one variable, if they have similar scales.

// The legend in the Figure is placed within the data region at 11 oclock: ring(0) position(11).
// It has two columns to parallel the side-by-side arrangement of bars. 
// symxsize(*.5) causes the horizontal (x) dimension of the symbols in the legend to appear at half their default size, 
// which saves space and also makes the symbols more similar to the widths of the bars themselves.
// The graph bar example above specifies a blue color for bar 1 and orange for bar 2. 

* Bar charts can provide clear visualizations of relationships involving many categories and two or more variables. 

* # Saving the graph

graph save Graph graph_bar.gph, replace
graph export graph_bar.png, as(png) replace
graph export graph_bar.eps, as(eps) replace
graph export graph_bar.emf, replace /* can insert in Word*/
* for Latex:
graph2tex, epsfile(graph_bar)
/* copy the resulting lines in Latex. Important: the graph has to be in the same folder as your main file into which you
want to include your graph.

In case yoo do not have any file yet, type in Latex the following three lines before the graph, then the lines for the graph
that you copied from the screen, then the last line "\end{document}". Your resulting code should look in the following way:

\documentclass{article}
\usepackage{graphicx}
\begin{document}

\begin{figure}[h]
\begin{centering}
  \includegraphics[height=3in]{readwrite}
\end{centering}
\end{figure}

\end{document}
*/

* The "graph save Graph" command saves the image (by default, temporarily named Graph as seen in the Graph window) in Statas .gph format. 
* We can always specify our own temporary name for a graph, by adding to the graph command an option such as "name(newgraph)". 
// Such temporary names for graphs become important when we have several graphs currently displayed, and want to save or print a particular one. 
// Giving a temporary name to the graph as we create it does not save that graph to disk.
// The temporary and saved-file names need not be the same. 
// Type "help name option" for more discussion.

* "graph export" commands create second and third versions of the same image in different formats. 
// Portable Network Graphics (.png) files are bitmapped images and have a fixed resolution, 
// but they are very compatible and easily shared through Web pages, Powerpoint presentations or other applications. 
// Encapsulated PostScript (.eps) is a high-quality vector format often preferred for publication. 
// Type "help graph export" to learn about other options for this command.

* # Pie Charts

* Pie charts rarely clarify the analysis but are popular for some public presentations. 

* The next Figure illustrates Statas graph pie command, showing the breakdown of world population by region. 
// To make the pie chart readable create a new variable, "popmil" or population in millions.

gen popmil = pop/1000000
summarize pop popmil

graph pie popmil, over(region) pie(2, explode) ///
plabel(_all sum, format(%4.0f))  ///
title("World population in millions, by region")  ///
legend(col(1) position(9)) 

// The pie(2, explode) option explodes the second pie slice (Americas) for emphasis. 
// plabel(_all sum, format(%4.0f)) requests labels for all of the pie slices, 
// giving the sum of popmil (that is, the total population in millions) for each region. 
// The pie labels have format(%4.0f), meaning a fixed numerical format with four digits, none right of the decimal.
// Type "help graph pie" to see other pie chart options, including methods for differently-organized data. 

// One interesting variation uses the by( ) option to create an image containing multiple small pie charts that can be visually compared.

* # Saving the graph

graph save Graph graph_pie.gph, replace
graph export graph_pie.png, as(png) replace
graph export graph_pie.eps, as(eps) replace


* ###########################################
* ### 3.7 Retrieving and Combining Graphs ###

* Any graph saved in Statas live .gph format can subsequently be retrieved into memory by the "graph use" command. 

graph use graph_bar.gph

* Once the graph is in memory, it is displayed onscreen and can be printed or saved again with a different name or format. 

* Graphs saved on disk can also be combined by the "graph combine" command. This provides a way to bring multiple plots into the same image.

graph combine ///
graph_bar.gph ///
graph_pie.gph ///
, rows(1) altshrink ///
title("Combining Figures", size(medium))

// The "rows(1)" option specified that the Figure should be arranged with the sub-graphs in one rows. 
// "altshrink" calls for alternate scaling of the text within each small image. 

// Note that we can request an overall title (or note, caption, ytitle, xtitle and so forth  not shown) for the combined image. 

// However, we cannot substantially change contents of the sub-graphs themselves.

graph save Graph graph_combined.gph, replace
graph export graph_combined.emf, as(emf) replace


* ########################
* ### 3.8 Graph Editor ###

* The Graph Editor allows us to alter the appearance of a graph currently in memory. 
// A first step is to retrieve this graph into memory.
// Then, in the Graph window, select File > Start Graph Editor, or click the Graph Editor icon.

graph use graph_bar.gph

// The view will change to include a Tools Toolbar on the left margin and an Object Browser on the right. 
// The Tools Toolbar contains a pointer tool for selecting parts of the graph, and other tools to add text, 
// add lines, add markers, and edit the graph grid. 
// The Object Browser presents a hierarchical list of graph contents. 
// Some items are marked with a + sign, and clicking on this + will expand the list to show lower objects within it. 
// We can select objects in the graph by clicking the pointer on their image, or by clicking names in the Object Browser (often easier in complex graphs).


* #####################################################
* ### 3.9 Symmetry and Quantile Plots [extra topic] ###

* Box plots, bar charts and histograms summarize measurement variable distributions, hiding individual data points to clarify overall patterns. 
* Symmetry and quantile plots, on the other hand, include points for every observation. 

* A histogram of the ratio of females to males in the labor forces of 177 countries, from Nations2.dta, appears in the next Figure. 

histogram femlab, norm percent

// A superimposed normal (Gaussian) curve indicates that femlab has a heavier-than-normal left tail 
// (countries with relatively few females in the labor force), 
// and a lighter-than-normal right tail  the definition of negative skew.

* The next Figure depicts this distribution as a symmetry plot. 

symplot femlab

// It plots the distance of the ith observation above the median (vertical) against the distance of the ith observation below the median. 
// All points would lie on the diagonal line if this distribution were symmetrical. 
// Instead, we see that distances below the median grow steadily larger than corresponding distances above the median, a symptom of negative skew.

* Quantile plots automatically calculate what fraction of the observations lie below each data value, 
// and display the results graphically as in the next Figure. 

quantile femlab, xlabel(0(.1)1, grid) ylabel(.2(.1)1, grid)

// Quantile plots provide a reference for someone who does not have the original data at hand. 
// From well-labeled quantile plots, we can estimate order statistics such as median (.5 quantile) or deciles (.1, .2, .3 quantiles and so forth). 
// We could also read a quantile plot to estimate the fraction of observations falling below a given value.

// Quantilenormal plots, also called normal probability plots, compare quantiles of a variables distribution
// with quantiles of a theoretical normal distribution having the same mean and standard deviation. 
// They allow visual inspection for departures from normality in every part of a distribution, 
// which can help guide decisions regarding normality assumptions and efforts to find a normalizing transformation. 

* The next Figure, a quantilenormal plot of femlab, confirms the negative skew noticed earlier. 
// The grid option calls for a set of lines marking the .05, .10, .25 (first quartile), .50 (median), 
// .75 (third quartile), .90, and .95 quantiles of both distributions. 
// The .05, .50, and .95 quantile values are displayed along the top and right-hand axes.

qnorm femlab, grid

* Quantilequantile plots (not shown) resemble quantilenormal plots, but compare quantiles (ordered data points) 
// of two empirical distributions instead of comparing one empirical distribution with a theoretical normal distribution. 
// Type "help quantile" for details on this graphical family.


* ###############################################
* ### 3.10 Adding Text to Graphs [extra topic] ###

* Titles, captions and notes can be added to make graphs more self-explanatory. 
// The default versions of titles and subtitles appear above the data region; 
// notes (which might document the data source, for instance) and captions appear below. 
// These defaults can be overridden.
// Type "help title options" for more information about placement of titles, 
// or "help textbox options" for details concerning their content, including font size and color.
